Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorxmujay <xmujay@gmail.com>2013-08-02 19:08:14 +0400
committerxmujay <xmujay@gmail.com>2013-08-02 19:08:14 +0400
commit6e6bd82cd12d1cb56e6f9c72142886ed711c184f (patch)
tree7eeb5b19ddc7a2c9168f838163c9aae07d1aad91 /server_variables.php
parentbe4f83eb96e93beda3d72a4ae9c8eca6d4f7ac65 (diff)
remove server_variables_doc.php and add a function to return doc links
Diffstat (limited to 'server_variables.php')
-rw-r--r--server_variables.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/server_variables.php b/server_variables.php
index b796c1b064..e832e9cf55 100644
--- a/server_variables.php
+++ b/server_variables.php
@@ -20,9 +20,9 @@ $scripts->addFile('server_variables.js');
require 'libraries/server_common.inc.php';
/**
* Required to display documentation links
*/
-require 'libraries/server_variables_doc.php';
+$variable_doc_links = PMA_getArrayForDocumentLinks();
/**
* Ajax request
@@ -31,9 +31,9 @@ require 'libraries/server_variables_doc.php';
if (isset($_REQUEST['ajax_request']) && $_REQUEST['ajax_request'] == true) {
if (isset($_REQUEST['type'])) {
if ($_REQUEST['type'] === 'getval') {
- PMA_getAjaxReturnForGetVal();
+ PMA_getAjaxReturnForGetVal($variable_doc_links);
} else if ($_REQUEST['type'] === 'setval') {
- PMA_getAjaxReturnForSetVal();
+ PMA_getAjaxReturnForSetVal($variable_doc_links);
}
exit;
}
@@ -55,7 +55,7 @@ $response->addHtml(PMA_getHtmlForLinkTemplates());
/**
* Displays the page
*/
-$response->addHtml(PMA_getHtmlForServerVariables());
+$response->addHtml(PMA_getHtmlForServerVariables($variable_doc_links));
exit;
@@ -20,9 +20,9 @@ $scripts->addFile('server_variables.js');
require 'libraries/server_common.inc.php';
/**
- * Required to display documentation links
+ * Array of documentation links
*/